==> edyuk-1.1.0.tar.bz2: edyuk-1.1.0/translations/assistant_untranslated.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>Assistant</name>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="158"/>
        <source>Open in current tab</source>
        <translation>Open in current tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="159"/>
        <source>Open in new tab</source>
        <translation>Open in new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="456"/>
        <source>Assistant</source>
        <translation>Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="253"/>
        <source>Content database not found.
Please run Qt Assistant to generate it.
</source>
        <translation>Content database not found.
Please run Qt Assistant to generate it.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="379"/>
        <source>Index database not found.
Please run Qt Assistant to generate it.
</source>
        <translation>Index database not found.
Please run Qt Assistant to generate it.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="461"/>
        <source>Search databases not found.
Please run Qt Assistant to generate them.
</source>
        <translation>Search databases not found.
Please run Qt Assistant to generate them.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="537"/>
        <source>Multiple links found</source>
        <translation>Multiple links found</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="538"/>
        <source>Select one : </source>
        <translation>Select one : </translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="659"/>
        <source>Full Text Search</source>
        <translation>Full Text Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="650"/>
        <source>Using a wildcard within phrases is not allowed.</source>
        <translation>Using a wildcard within phrases is not allowed.</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="660"/>
        <source>The closing quotation mark is missing.</source>
        <translation>The closing quotation mark is missing.</translation>
    </message>
</context>
<context>
    <name>AssistantClient</name>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="402"/>
        <source>Address : </source>
        <translation>Address : </translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="404"/>
        <source>Forward</source>
        <translation>Forward</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="332"/>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="405"/>
        <source>Backward</source>
        <translation>Backward</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="406"/>
        <source>Reload</source>
        <translation>Reload</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="407"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="408"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="410"/>
        <source>Open link</source>
        <translation>Open link</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="411"/>
        <source>Open in new tab</source>
        <translation>Open in new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="413"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="471"/>
        <source>Assistant : %1</source>
        <translation>Assistant : %1</translation>
    </message>
</context>
<context>
    <name>AssistantPerspective</name>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="312"/>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="308"/>
        <source>&amp;Search</source>
        <translation>&amp;Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="299"/>
        <source>&amp;Contents</source>
        <translation>&amp;Contents</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="300"/>
        <source>&amp;Index</source>
        <translation>&amp;Index</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="303"/>
        <source>Preparing...</source>
        <translation>Preparing...</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="304"/>
        <source>Select profile :</source>
        <translation>Select profile :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="306"/>
        <source>Text to find :</source>
        <translation>Text to find :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="324"/>
        <source>C++ source files ( *.cpp *.c *.cxx *.cc )</source>
        <translation>C++ source files ( *.cpp *.c *.cxx *.cc )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="325"/>
        <source>C++ header files ( *.h *.hpp *.hxx )</source>
        <translation>C++ header files ( *.h *.hpp *.hxx )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="326"/>
        <source>Qt resource files ( *.qrc )</source>
        <translation>Qt resource files ( *.qrc )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="327"/>
        <source>Qt Linguist translations ( *.ts )</source>
        <translation>Qt Linguist translations ( *.ts )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="114"/>
        <source>Filter :</source>
        <translation>Filter :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="483"/>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="484"/>
        <source>Open in &amp;new tab</source>
        <translation>Open in &amp;new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="633"/>
        <source>Multiple links</source>
        <translation>Multiple links</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="634"/>
        <source>Choose the most appropriate : </source>
        <translation>Choose the most appropriate : </translation>
    </message>
</context>
<context>
    <name>AssistantPlugin</name>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="95"/>
        <source>Search on type</source>
        <translation>Search on type</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="92"/>
        <source>Qt4 perspective</source>
        <translation>Qt4 perspective</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="94"/>
        <source>Assistant integration</source>
        <translation>Assistant integration</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="93"/>
        <source>A simple perspective bringing some more Qt4-related features like graphical management of Qt resource files and Assistant integration.</source>
        <translation>A simple perspective bringing some more Qt4-related features like graphical management of Qt resource files and Assistant integration.</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/plugins/assistant/index.cpp" line="394"/>
        <source>Untitled</source>
        <translation>Untitled</translation>
    </message>
</context>
<context>
    <name>QRCEdit</name>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="163"/>
        <source>Add resource</source>
        <translation>Add resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="164"/>
        <source>Remove resource</source>
        <translation>Remove resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="165"/>
        <source>Resource prefix</source>
        <translation>Resource prefix</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="156"/>
        <source>Resource content</source>
        <translation>Resource content</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="158"/>
        <source>Absolute :</source>
        <translation>Absolute :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="159"/>
        <source>Alias :</source>
        <translation>Alias :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="161"/>
        <source>&lt;h5&gt;Preview :&lt;/h5&gt;</source>
        <translation>&lt;h5&gt;Preview :&lt;/h5&gt;</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="167"/>
        <source>Add file</source>
        <translation>Add file</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="168"/>
        <source>Remove file</source>
        <translation>Remove file</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="171"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="195"/>
        <source>Unable to read %1</source>
        <translation>Unable to read %1</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="236"/>
        <source>Unable to write %1</source>
        <translation>Unable to write %1</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="274"/>
        <source>Creating new resource</source>
        <translation>Creating new resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="275"/>
        <source>Enter the resource prefix :</source>
        <translation>Enter the resource prefix :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="327"/>
        <source>Setting resource prefix</source>
        <translation>Setting resource prefix</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="328"/>
        <source>Enter the new resource prefix :</source>
        <translation>Enter the new resource prefix :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="360"/>
        <source>Ading file(s) to resource</source>
        <translation>Ading file(s) to resource</translation>
    </message>
</context>
<context>
    <name>Search</name>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="13"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="88"/>
        <source>Close search/replace panel</source>
        <translation>Close search/replace panel</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="107"/>
        <source> Find :</source>
        <translation> Find :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="135"/>
        <source>Text or pattern to search for</source>
        <translation>Text or pattern to search for</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="154"/>
        <source>Find next occurence</source>
        <translation>Find next occurence</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="179"/>
        <source>Find previous occurence</source>
        <translation>Find previous occurence</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="214"/>
        <source>Whole words</source>
        <translation>Whole words</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="227"/>
        <source>From cursor</source>
        <translation>From cursor</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="243"/>
        <source>Regexp</source>
        <translation>Regexp</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="256"/>
        <source>Match case</source>
        <translation>Match case</translation>
    </message>
</context>
</TS>

==> edyuk-1.1.1.tar.bz2: edyuk-1.1.1/translations/assistant_untranslated.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>Assistant</name>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="158"/>
        <source>Open in current tab</source>
        <translation>Open in current tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="159"/>
        <source>Open in new tab</source>
        <translation>Open in new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="248"/>
        <location filename="../src/plugins/assistant/assistant.cpp" line="374"/>
        <location filename="../src/plugins/assistant/assistant.cpp" line="456"/>
        <source>Assistant</source>
        <translation>Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="249"/>
        <source>Content database not found.
Please run Qt Assistant to generate it.
</source>
        <translation>Content database not found.
Please run Qt Assistant to generate it.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="375"/>
        <source>Index database not found.
Please run Qt Assistant to generate it.
</source>
        <translation>Index database not found.
Please run Qt Assistant to generate it.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="457"/>
        <source>Search databases not found.
Please run Qt Assistant to generate them.
</source>
        <translation>Search databases not found.
Please run Qt Assistant to generate them.
</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="537"/>
        <source>Multiple links found</source>
        <translation>Multiple links found</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="538"/>
        <source>Select one : </source>
        <translation>Select one : </translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="649"/>
        <location filename="../src/plugins/assistant/assistant.cpp" line="659"/>
        <source>Full Text Search</source>
        <translation>Full Text Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="650"/>
        <source>Using a wildcard within phrases is not allowed.</source>
        <translation>Using a wildcard within phrases is not allowed.</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistant.cpp" line="660"/>
        <source>The closing quotation mark is missing.</source>
        <translation>The closing quotation mark is missing.</translation>
    </message>
</context>
<context>
    <name>AssistantClient</name>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="288"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="402"/>
        <source>Address : </source>
        <translation>Address : </translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="305"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="404"/>
        <source>Forward</source>
        <translation>Forward</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="307"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="315"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="322"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="327"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="332"/>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="313"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="405"/>
        <source>Backward</source>
        <translation>Backward</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="321"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="406"/>
        <source>Reload</source>
        <translation>Reload</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="326"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="407"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="331"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="408"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="336"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="410"/>
        <source>Open link</source>
        <translation>Open link</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="340"/>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="411"/>
        <source>Open in new tab</source>
        <translation>Open in new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="413"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantclient.cpp" line="471"/>
        <source>Assistant : %1</source>
        <translation>Assistant : %1</translation>
    </message>
</context>
<context>
    <name>AssistantPerspective</name>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="101"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="311"/>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="134"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="204"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="224"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="300"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="307"/>
        <source>&amp;Search</source>
        <translation>&amp;Search</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="132"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="222"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="298"/>
        <source>&amp;Contents</source>
        <translation>&amp;Contents</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="133"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="223"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="299"/>
        <source>&amp;Index</source>
        <translation>&amp;Index</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="252"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="302"/>
        <source>Preparing...</source>
        <translation>Preparing...</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="303"/>
        <source>Select profile :</source>
        <translation>Select profile :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="304"/>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="305"/>
        <source>Text to find :</source>
        <translation>Text to find :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="322"/>
        <source>C++ source files ( *.cpp *.c *.cxx *.cc )</source>
        <translation>C++ source files ( *.cpp *.c *.cxx *.cc )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="323"/>
        <source>C++ header files ( *.h *.hpp *.hxx )</source>
        <translation>C++ header files ( *.h *.hpp *.hxx )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="324"/>
        <source>Qt resource files ( *.qrc )</source>
        <translation>Qt resource files ( *.qrc )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="325"/>
        <source>Qt Linguist translations ( *.ts )</source>
        <translation>Qt Linguist translations ( *.ts )</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="113"/>
        <source>Filter :</source>
        <translation>Filter :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="482"/>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="483"/>
        <source>Open in &amp;new tab</source>
        <translation>Open in &amp;new tab</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="632"/>
        <source>Multiple links</source>
        <translation>Multiple links</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/assistantperspective.cpp" line="633"/>
        <source>Choose the most appropriate : </source>
        <translation>Choose the most appropriate : </translation>
    </message>
</context>
<context>
    <name>AssistantPlugin</name>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="101"/>
        <source>Search on type</source>
        <translation>Search on type</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="98"/>
        <source>Qt4 perspective</source>
        <translation>Qt4 perspective</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="100"/>
        <source>Assistant integration</source>
        <translation>Assistant integration</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/plugin.cpp" line="99"/>
        <source>A simple perspective bringing some more Qt4-related features like graphical management of Qt resource files and Assistant integration.</source>
        <translation>A simple perspective bringing some more Qt4-related features like graphical management of Qt resource files and Assistant integration.</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/plugins/assistant/index.cpp" line="394"/>
        <source>Untitled</source>
        <translation>Untitled</translation>
    </message>
</context>
<context>
    <name>QRCEdit</name>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="65"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="77"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="81"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="163"/>
        <source>Add resource</source>
        <translation>Add resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="69"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="164"/>
        <source>Remove resource</source>
        <translation>Remove resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="73"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="165"/>
        <source>Resource prefix</source>
        <translation>Resource prefix</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="156"/>
        <source>Resource content</source>
        <translation>Resource content</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="158"/>
        <source>Absolute :</source>
        <translation>Absolute :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="159"/>
        <source>Alias :</source>
        <translation>Alias :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="161"/>
        <source>&lt;h5&gt;Preview :&lt;/h5&gt;</source>
        <translation>&lt;h5&gt;Preview :&lt;/h5&gt;</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="167"/>
        <source>Add file</source>
        <translation>Add file</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="168"/>
        <source>Remove file</source>
        <translation>Remove file</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="170"/>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="171"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="195"/>
        <source>Unable to read %1</source>
        <translation>Unable to read %1</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="236"/>
        <source>Unable to write %1</source>
        <translation>Unable to write %1</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="274"/>
        <source>Creating new resource</source>
        <translation>Creating new resource</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="275"/>
        <source>Enter the resource prefix :</source>
        <translation>Enter the resource prefix :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="327"/>
        <source>Setting resource prefix</source>
        <translation>Setting resource prefix</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="328"/>
        <source>Enter the new resource prefix :</source>
        <translation>Enter the new resource prefix :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/qrcedit.cpp" line="360"/>
        <source>Ading file(s) to resource</source>
        <translation>Ading file(s) to resource</translation>
    </message>
</context>
<context>
    <name>Search</name>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="13"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="88"/>
        <source>Close search/replace panel</source>
        <translation>Close search/replace panel</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="107"/>
        <source> Find :</source>
        <translation> Find :</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="135"/>
        <source>Text or pattern to search for</source>
        <translation>Text or pattern to search for</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="154"/>
        <source>Find next occurence</source>
        <translation>Find next occurence</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="179"/>
        <source>Find previous occurence</source>
        <translation>Find previous occurence</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="214"/>
        <source>Whole words</source>
        <translation>Whole words</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="227"/>
        <source>From cursor</source>
        <translation>From cursor</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="243"/>
        <source>Regexp</source>
        <translation>Regexp</translation>
    </message>
    <message>
        <location filename="../src/plugins/assistant/search.ui" line="256"/>
        <source>Match case</source>
        <translation>Match case</translation>
    </message>
</context>
</TS>
